# Other Related Datasets or Tools

## Mixture

- [WHAM! and WHAMR!](https://wham.whisper.ai/)
- [JorisCos/LibriMix](https://github.com/JorisCos/LibriMix)
- [fgnt/sms_wsj](https://github.com/fgnt/sms_wsj): Spatialized Multi-Speaker Wall Street Journal database for
  multi-channel source separation and recognition
- [fgnt/mms_msg](https://github.com/fgnt/mms_msg): Multipurpose Multi Speaker Mixture Signal Generator..
- [fgnt/lazy_dataset](https://github.com/fgnt/lazy_dataset): Process large datasets as if it was an iterable...
- [fgnt/paderbox](https://github.com/fgnt/paderbox): Paderbox: A collection of utilities for audio / speech processing..
- [tomkocse/sim-rir-preparation](https://github.com/tomkocse/sim-rir-preparation)

## Room Impulse Response

Collect publicly available room impulse response datasets.

- [RoyJames/room-impulse-responses](https://github.com/RoyJames/room-impulse-responses): A list of publicly available
  room impulse response datasets and scripts to download them...
